@@ -1,4 +1,5 @@
 ## ----global_options, include=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+old <- options()
 options(width = 999)
 knitr::opts_chunk$set(fig.align='center', fig.width=5.5, fig.height=4.5, message=FALSE)
 
@@ -87,3 +88,6 @@ int.clean.fm <- intensityMatrix(peaks.clean.fm)
 #  writeIntensity(int.clean.fm, file = file.path(tempdir(),"int.clean.fm"),
 #                 format = "NEXUS", labels = type.clean.fm)
 
+## ----global_options_exit, include=FALSE---------------------------------------
+options(old)
+
